@@ -1,4 +1,4 @@
-import abc
+from __future__ import absolute_import, division, print_function
 
 from ispyb.interface.dataarea import DataArea
 
